@@ -161,6 +161,11 @@ class LidarScene:
         for frame in self.frames:
             frame.transform = offset @ frame.transform
 
+    def downsample_scene(self, voxel_size_mm: int = 250):
+        """Downsamples all frames according to voxel size"""
+        for idx in range(len(self.frames)):
+            self.get_frame(index=idx).downsample_frame(voxel_size_mm=voxel_size_mm)
+
     def to_dict(self, base_url: str = None) -> dict:
         """Return a dictionary with the frame urls using the base_url as base.
 
@@ -238,8 +243,7 @@ class LidarScene:
         return self.base_url
 
     def scale_file_upload(
-        self,
-        project_name: str,
+        self, project_name: str,
     ):
         """Save scene in Scale file
 
